<?php
/*
  This code is part of GOsa (https://gosa.gonicus.de)
  Copyright (C) 2003  Cajus Pollmeier

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


/* Basic setup, remove eventually registered sessions */
require_once ("../include/php_setup.inc");
require_once ("functions.inc");
session_start ();

/* Do logout-logging and destroy session */
if (!isset($_SESSION["ui"])){
	header ("Location: index.php");
	exit;
}
$ui= $_SESSION["ui"];
$config= $_SESSION["config"];
gosa_log ("User \"".$ui->username."\" logged out");

# Remove all locks of this user
del_user_locks($ui->dn);

@session_destroy ();

/* Go back to the base via header */
header ("Location: index.php");

?>

